import json
import asyncio
from fastapi import APIRouter, Depends
from sqlalchemy.orm import Session
from starlette.responses import StreamingResponse
from app.models import JobStatus, Jobs as JobModel
from app.dependencies import get_db

router = APIRouter()


async def job_event_generator(db: Session):
    while True:
        # Fetch jobs with status TODO
        jobs = db.query(JobModel).filter(JobModel.status == JobStatus.TODO).all()

        if jobs:
            # It's recommended to explicitly communicate IDs clearly
            job_payload = [{"id": job.id, "parameters": job.parameters} for job in jobs]
            yield f"data: {json.dumps(job_payload)}\n\n"

        await asyncio.sleep(5)  # A reasonable heartbeat/refresh


@router.get("/jobs/stream")
async def stream_jobs(db: Session = Depends(get_db)):
    return StreamingResponse(job_event_generator(db), media_type="text/event-stream")
